@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Accuracy tests for GCRS coordinate transformations, primarily to/from AltAz.
+"""Accuracy tests for GCRS coordinate transformations, primarily to/from AltAz."""
 
-"""
 import warnings
 from importlib import metadata
 
@@ -748,7 +747,7 @@ def test_teme_itrf():
     Test case transform from TEME to ITRF.
 
     Test case derives from example on appendix C of Vallado, Crawford, Hujsak & Kelso (2006).
-    See https://celestrak.com/publications/AIAA/2006-6753/AIAA-2006-6753-Rev2.pdf
+    See https://celestrak.org/publications/AIAA/2006-6753/AIAA-2006-6753-Rev2.pdf
     """
     v_itrf = CartesianDifferential(
         -3.225636520, -2.872451450, 5.531924446, unit=u.km / u.s
