@@ -133,9 +133,9 @@ class _ImageBaseHDU(_ValidHDU):
         # Set the name attribute if it was provided (if this is an ImageHDU
         # this will result in setting the EXTNAME keyword of the header as
         # well)
-        if "name" in kwargs and kwargs["name"]:
+        if kwargs.get("name"):
             self.name = kwargs["name"]
-        if "ver" in kwargs and kwargs["ver"]:
+        if kwargs.get("ver"):
             self.ver = kwargs["ver"]
 
         # Set to True if the data or header is replaced, indicating that
@@ -272,7 +272,7 @@ class _ImageBaseHDU(_ValidHDU):
                     data = np.array(data)
                 except Exception:  # pragma: no cover
                     raise TypeError(
-                        f"data object {data!r} could not be coerced into an " f"ndarray"
+                        f"data object {data!r} could not be coerced into an ndarray"
                     )
 
             if data.shape == ():
@@ -283,7 +283,7 @@ class _ImageBaseHDU(_ValidHDU):
         self.__dict__["data"] = data
         self._modified = True
 
-        if self.data is None:
+        if data is None:
             self._axes = []
         else:
             # Set new values of bitpix, bzero, and bscale now, but wait to
@@ -548,7 +548,7 @@ class _ImageBaseHDU(_ValidHDU):
                 # We have to explicitly cast _zero to prevent numpy from raising an
                 # error when doing self.data -= zero, and we do this instead of
                 # self.data = self.data - zero to avoid doubling memory usage.
-                np.add(self.data, -_zero, out=self.data, casting="unsafe")
+                self.data -= np.array(_zero).astype(self.data.dtype, casting="unsafe")
             self._header["BZERO"] = _zero
         else:
             try:
@@ -610,9 +610,9 @@ class _ImageBaseHDU(_ValidHDU):
         # should be handled by the schema
         if not _is_int(self._blank):
             messages.append(
-                "Invalid value for 'BLANK' keyword in header: {!r} "
+                f"Invalid value for 'BLANK' keyword in header: {self._blank!r} "
                 "The 'BLANK' keyword must be an integer.  It will be "
-                "ignored in the meantime.".format(self._blank)
+                "ignored in the meantime."
             )
             self._blank = None
         if not self._bitpix > 0:
@@ -1050,7 +1050,8 @@ class Section:
             if isinstance(key, slice):
                 ks = range(*key.indices(axis))
                 break
-            elif isiterable(key):
+
+            if isiterable(key):
                 # Handle both integer and boolean arrays.
                 ks = np.arange(axis, dtype=int)[key]
                 break
