@@ -84,7 +84,7 @@ def read_table_parquet(
     ``value`` must be a collection such as a ``list``, a ``set`` or a
     ``tuple``.
 
-    Examples:
+    For example:
 
     .. code-block:: python
 
@@ -132,7 +132,7 @@ def read_table_parquet(
     else:
         md = {}
 
-    from astropy.table import Table, meta, serialize
+    from astropy.table import Column, Table, meta, serialize
 
     # parse metadata from table yaml
     meta_dict = {}
@@ -173,7 +173,7 @@ def read_table_parquet(
         names = [n for n, col in full_table_columns.items() if name == col]
         names_to_read.extend(names)
 
-    if not names_to_read:
+    if full_table_columns and not names_to_read:
         raise ValueError("No include_names specified were found in the table.")
 
     # We need to pop any unread serialized columns out of the meta_dict.
@@ -190,15 +190,32 @@ def read_table_parquet(
     else:
         num_rows = 0
 
-    # Now need to convert parquet table to Astropy
+    # Determine numpy/astropy types of columns from the arrow table.
     dtype = []
     for name in names_to_read:
-        # Pyarrow string and byte columns do not have native length information
-        # so we must determine those here.
-        if schema.field(name).type not in (pa.string(), pa.binary()):
-            # Convert the pyarrow type into a numpy dtype (which is returned
+        t = schema.field(name).type
+
+        shape = None
+
+        if isinstance(t, pa.FixedSizeListType):
+            # The FixedSizeListType has an arrow value_type and a size.
+            value_type = t.value_type
+            shape = (t.list_size,)
+        elif isinstance(t, pa.ListType):
+            # The ListType (variable length arrays) has a value type.
+            value_type = t.value_type
+        else:
+            # All other arrow column types are the value_type.
+            value_type = t
+
+        if value_type not in (pa.string(), pa.binary()):
+            # Convert the pyarrow value type into a numpy dtype (which is returned
             # by the to_pandas_type() method).
-            dtype.append(schema.field(name).type.to_pandas_dtype())
+            # If this is an array column, the numpy dtype needs the shape as well.
+            if shape is None:
+                dtype.append(value_type.to_pandas_dtype())
+            else:
+                dtype.append((value_type.to_pandas_dtype(), shape))
             continue
 
         # Special-case for string and binary columns
@@ -221,19 +238,55 @@ def read_table_parquet(
                 f" ({strlen} characters).",
                 AstropyUserWarning,
             )
-        dtype.append(
-            f"U{strlen}" if schema.field(name).type == pa.string() else f"|S{strlen}"
-        )
+        strname = f"U{strlen}" if value_type == pa.string() else f"|S{strlen}"
 
-    # Create the empty numpy record array to store the pyarrow data.
-    data = np.zeros(num_rows, dtype=list(zip(names_to_read, dtype)))
+        # If this is an array column, the numpy dtype needs the shape as well.
+        if shape is None:
+            dtype.append(strname)
+        else:
+            dtype.append((strname, shape))
 
-    if not schema_only:
-        # Convert each column in the pyarrow table to a numpy array
-        for name in names_to_read:
-            data[name][:] = pa_table[name].to_numpy()
+    if schema_only:
+        # If we only need the schema, create an empty table with the correct dtype.
+        data = np.zeros(0, dtype=list(zip(names_to_read, dtype)))
+        table = Table(data=data, meta=meta_dict)
+    else:
+        # If we need the full table, create the table and add the columns
+        # one at a time. This minimizes data copying.
 
-    table = Table(data=data, meta=meta_dict)
+        table = Table(meta=meta_dict)
+        for name, dt in zip(names_to_read, dtype):
+            # First convert the arrow column to a numpy array.
+            col = pa_table[name].to_numpy()
+
+            t = schema.field(name).type
+            if t in (pa.string(), pa.binary()):
+                # If it is a string/binary type, coerce it to the correct type.
+                col = col.astype(dt)
+            elif isinstance(t, pa.FixedSizeListType):
+                # If it is a FixedSizeListType (array column) then it needs to
+                # be broken into a 2D array, but only if the table has a non-zero
+                # length.
+                if len(col) > 0:
+                    col = np.stack(col)
+
+                    if t.value_type in (pa.string(), pa.binary()):
+                        # If it is a string/binary type, coerce it to the
+                        # correct type.
+                        # The conversion dtype is only the first element
+                        # in the dtype tuple.
+                        col = col.astype(dt[0])
+                else:
+                    # This is an empty column, and needs to be created with the
+                    # correct type.
+                    col = np.zeros(0, dtype=dt)
+            elif isinstance(t, pa.ListType):
+                # If we have a variable length string/binary column,
+                # we need to convert each row to the proper type.
+                if t.value_type in (pa.string(), pa.binary()):
+                    col = np.array([row.astype(dt) for row in col], dtype=np.object_)
+
+            table.add_column(Column(name=name, data=col))
 
     if meta_hdr is not None:
         # Set description, format, unit, meta from the column
@@ -253,7 +306,11 @@ def read_table_parquet(
 
 def write_table_parquet(table, output, overwrite=False):
     """
-    Write a Table object to a Parquet file
+    Write a Table object to a Parquet file.
+
+    The parquet writer supports tables with regular columns, fixed-size array
+    columns, and variable-length array columns (provided all arrays have the
+    same type).
 
     This requires `pyarrow <https://arrow.apache.org/docs/python/>`_
     to be installed.
@@ -266,8 +323,19 @@ def write_table_parquet(table, output, overwrite=False):
         The filename to write the table to.
     overwrite : bool, optional
         Whether to overwrite any existing file without warning. Default `False`.
-    """
 
+    Notes
+    -----
+    Tables written with array columns (fixed-size or variable-length) cannot
+    be read with pandas.
+
+    Raises
+    ------
+    ValueError
+        If one of the columns has a mixed-type variable-length array, or
+        if it is a zero-length table and any of the columns are variable-length
+        arrays.
+    """
     from astropy.table import meta, serialize
     from astropy.utils.data_info import serialize_context_as
 
@@ -284,15 +352,70 @@ def write_table_parquet(table, output, overwrite=False):
     meta_yaml = meta.get_yaml_from_table(encode_table)
     meta_yaml_str = "\n".join(meta_yaml)
 
+    # Build the pyarrow schema by converting from the numpy dtype of each
+    # column to an equivalent pyarrow type with from_numpy_dtype()
+    type_list = []
+    for name in encode_table.dtype.names:
+        dt = encode_table.dtype[name]
+        if dt.type == np.object_:
+            # If the column type is np.object_, then it should be a column
+            # of variable-length arrays. This can be serialized with parquet
+            # provided all of the elements have the same data-type.
+            # Additionally, if the table has no elements, we cannot deduce
+            # the datatype, and hence cannot serialize the table.
+            if len(encode_table) > 0:
+                obj_dtype = encode_table[name][0].dtype
+
+                # Check that the variable-length array all has the same type.
+                for row in encode_table[name]:
+                    if row.dtype != obj_dtype:
+                        raise ValueError(
+                            f"Cannot serialize mixed-type column ({name}) with parquet."
+                        )
+                # Calling pa.list_() creates a ListType which is an array of variable-
+                # length elements.
+                arrow_type = pa.list_(
+                    value_type=pa.from_numpy_dtype(obj_dtype.type),
+                )
+            else:
+                raise ValueError(
+                    "Cannot serialize zero-length table "
+                    f"with object column ({name}) with parquet."
+                )
+        elif len(dt.shape) > 0:
+            # This column has a shape, and is an array type column.  Calling
+            # pa.list_() with a list_size creates a FixedSizeListType, which
+            # is an array of fixed-length elements.
+            arrow_type = pa.list_(
+                value_type=pa.from_numpy_dtype(dt.subdtype[0].type),
+                list_size=np.prod(dt.shape),
+            )
+        else:
+            # This is a standard column.
+            arrow_type = pa.from_numpy_dtype(dt.type)
+
+        type_list.append((name, arrow_type))
+
     metadata = {}
     for name, col in encode_table.columns.items():
         # Parquet will retain the datatypes of columns, but string and
         # byte column length is lost.  Therefore, we special-case these
         # types to record the length for precise round-tripping.
-        if col.dtype.type is np.str_:
-            metadata[f"table::len::{name}"] = str(col.dtype.itemsize // 4)
-        elif col.dtype.type is np.bytes_:
-            metadata[f"table::len::{name}"] = str(col.dtype.itemsize)
+
+        t = col.dtype.type
+        itemsize = col.dtype.itemsize
+        if t is np.object_:
+            t = encode_table[name][0].dtype.type
+            if t == np.str_ or t == np.bytes_:
+                # We need to scan through all of them.
+                itemsize = -1
+                for row in encode_table[name]:
+                    itemsize = max(itemsize, row.dtype.itemsize)
+
+        if t is np.str_:
+            metadata[f"table::len::{name}"] = str(itemsize // 4)
+        elif t is np.bytes_:
+            metadata[f"table::len::{name}"] = str(itemsize)
 
         metadata["table_meta_yaml"] = meta_yaml_str
 
@@ -302,12 +425,6 @@ def write_table_parquet(table, output, overwrite=False):
         k.encode("UTF-8"): v.encode("UTF-8") for k, v in metadata.items()
     }
 
-    # Build the pyarrow schema by converting from the numpy dtype of each
-    # column to an equivalent pyarrow type with from_numpy_dtype()
-    type_list = [
-        (name, pa.from_numpy_dtype(encode_table.dtype[name].type))
-        for name in encode_table.dtype.names
-    ]
     schema = pa.schema(type_list, metadata=metadata_encode)
 
     if os.path.exists(output):
@@ -320,7 +437,29 @@ def write_table_parquet(table, output, overwrite=False):
     # We use version='2.0' for full support of datatypes including uint32.
     with parquet.ParquetWriter(output, schema, version=writer_version) as writer:
         # Convert each Table column to a pyarrow array
-        arrays = [pa.array(col) for col in encode_table.itercols()]
+        arrays = []
+        for name in encode_table.dtype.names:
+            dt = encode_table.dtype[name]
+            # Parquet must be stored little-endian.  When we use astype(..., copy=False)
+            # we get a very fast conversion when the dtype is unchanged, and only
+            # incur a cost when we need to do a byte-swap operation.
+            dt_new = dt.newbyteorder("<")
+            if dt.type == np.object_:
+                # Turn the column into a list of numpy arrays.
+                val = [row.astype(dt_new, copy=False) for row in encode_table[name]]
+            elif len(dt.shape) > 0:
+                if len(encode_table) > 0:
+                    val = np.split(
+                        encode_table[name].ravel().astype(dt_new.base, copy=False),
+                        len(encode_table),
+                    )
+                else:
+                    val = []
+            else:
+                val = encode_table[name].astype(dt_new, copy=False)
+
+            arrays.append(pa.array(val, type=schema.field(name).type))
+
         # Create a pyarrow table from the list of arrays and the schema
         pa_table = pa.Table.from_arrays(arrays, schema=schema)
         # Write the pyarrow table to a file
