@@ -7,14 +7,15 @@ The corresponding magnitudes are given in the description of each unit
 (the actual definitions are in `~astropy.units.function.logarithmic`).
 """
 
-
-import numpy as _numpy
+import numpy as np
 
 from astropy.constants import si as _si
 
 from . import astrophys, cgs, si
 from .core import Unit, UnitBase, def_unit
 
+__all__ = ["zero_point_flux"]  #  Units are added at the end
+
 _ns = globals()
 
 def_unit(
@@ -29,11 +30,11 @@ def_unit(
 )
 def_unit(
     ["bol", "f_bol"],
-    _si.L_bol0 / (4 * _numpy.pi * (10.0 * astrophys.pc) ** 2),
+    _si.L_bol0 / (4 * np.pi * (10.0 * astrophys.pc) ** 2),
     namespace=_ns,
     prefixes=False,
     doc=(
-        "Irradiance corresponding to appparent bolometric magnitude zero "
+        "Irradiance corresponding to apparent bolometric magnitude zero "
         "(magnitude ``m_bol``)."
     ),
 )
@@ -78,18 +79,14 @@ def zero_point_flux(flux0):
 
 
 ###########################################################################
-# CLEANUP
+# ALL & DOCSTRING
 
-del UnitBase
-del def_unit
-del cgs, si, astrophys
+__all__ += [n for n, v in _ns.items() if isinstance(v, UnitBase)]
 
-###########################################################################
-# DOCSTRING
-
-# This generates a docstring for this module that describes all of the
-# standard units defined here.
-from .utils import generate_unit_summary as _generate_unit_summary
 
 if __doc__ is not None:
+    # This generates a docstring for this module that describes all of the
+    # standard units defined here.
+    from .utils import generate_unit_summary as _generate_unit_summary
+
     __doc__ += _generate_unit_summary(globals())
