@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import matplotlib.lines
 import matplotlib.pyplot as plt
+import matplotlib.text
 import numpy as np
 import pytest
 from matplotlib import rc_context
@@ -365,6 +366,31 @@ class TestBasic(BaseImageTests):
 
         return fig
 
+    @figure_test
+    def test_text_coord(self):
+        fig = plt.figure(figsize=(6, 6))
+        ax = fig.add_axes(
+            [0.15, 0.15, 0.8, 0.8],
+            projection=WCS(self.twoMASS_k_header),
+            aspect="equal",
+        )
+        ax.set_xlim(-0.5, 720.5)
+        ax.set_ylim(-0.5, 720.5)
+
+        c = SkyCoord(266 * u.deg, -29 * u.deg)
+        text = ax.text_coord(c, "Sample Label", color="blue", ha="right", va="top")
+
+        # Test that plot_coord returns the results from ax.text
+        assert isinstance(text, matplotlib.text.Text)
+
+        # In previous versions, all angle axes defaulted to being displayed in
+        # degrees. We now automatically show RA axes in hour angle units, but
+        # for backward-compatibility with previous reference images we
+        # explicitly use degrees here.
+        ax.coords[0].set_format_unit(u.degree)
+
+        return fig
+
     @figure_test
     def test_plot_line(self):
         fig = plt.figure(figsize=(6, 6))
@@ -751,7 +777,7 @@ class TestBasic(BaseImageTests):
         with pytest.warns(
             AstropyUserWarning,
             match="Received `center` of representation type "
-            "<class 'astropy.coordinates.representation.CartesianRepresentation'> "
+            "<class 'astropy.coordinates.*CartesianRepresentation'> "
             "will be converted to SphericalRepresentation",
         ):
             r3 = SphericalCircle(
@@ -890,7 +916,7 @@ class TestBasic(BaseImageTests):
 
     @figure_test
     def test_hms_labels(self):
-        # This tests the apparance of the hms superscripts in tick labels
+        # This tests the appearance of the hms superscripts in tick labels
         fig = plt.figure(figsize=(3, 3))
         ax = fig.add_axes(
             [0.3, 0.2, 0.65, 0.6], projection=WCS(self.twoMASS_k_header), aspect="equal"
